@@ -12,7 +12,7 @@ from behave import given, when, then
 
 from pptx import Presentation
 from pptx.enum.text import PP_ALIGN
-from pptx.util import Inches
+from pptx.util import Emu, Inches
 
 from .helpers import saved_pptx_path, test_pptx
 
@@ -35,6 +35,34 @@ def given_a_paragraph_containing_text(context):
     context.paragraph = prs.slides[0].shapes[0].text_frame.paragraphs[0]
 
 
+@given('a paragraph having line spacing of {setting}')
+def given_a_paragraph_having_line_spacing_of_setting(context, setting):
+    paragraph_idx = {
+        'no explicit setting': 0,
+        '1.5 lines':           1,
+        '20 pt':               2,
+    }[setting]
+    prs = Presentation(test_pptx('txt-paragraph-spacing'))
+    text_frame = prs.slides[2].shapes[0].text_frame
+    context.paragraph = text_frame.paragraphs[paragraph_idx]
+
+
+@given('a paragraph having space {before_after} of {setting}')
+def given_a_paragraph_having_space_before_after_of_setting(
+        context, before_after, setting):
+    slide_idx = {
+        'before': 0,
+        'after':  1,
+    }[before_after]
+    paragraph_idx = {
+        'no explicit setting': 0,
+        '6 pt':                1,
+    }[setting]
+    prs = Presentation(test_pptx('txt-paragraph-spacing'))
+    text_frame = prs.slides[slide_idx].shapes[0].text_frame
+    context.paragraph = text_frame.paragraphs[paragraph_idx]
+
+
 @given('a run')
 def given_a_run(context):
     prs = Presentation(test_pptx('txt-text'))
@@ -97,6 +125,35 @@ def when_assign_typeface_name_to_font(context):
     context.font.name = 'Verdana'
 
 
+@when('I assign {value_str} to paragraph.line_spacing')
+def when_I_assign_value_to_paragraph_line_spacing(context, value_str):
+    value = {
+        '1.5':    1.5,
+        '2.0':    2.0,
+        '254000': Emu(254000),
+        '304800': Emu(304800),
+        'None':   None,
+    }[value_str]
+    paragraph = context.paragraph
+    paragraph.line_spacing = value
+
+
+@when('I assign {value_str} to paragraph.space_{before_after}')
+def when_I_assign_value_to_paragraph_space_before_after(
+        context, value_str, before_after):
+    value = {
+        '76200': 76200,
+        '38100': 38100,
+        'None':  None,
+    }[value_str]
+    attr_name = {
+        'before': 'space_before',
+        'after':  'space_after',
+    }[before_after]
+    paragraph = context.paragraph
+    setattr(paragraph, attr_name, value)
+
+
 @when('I reload the presentation')
 def when_reload_presentation(context):
     if os.path.isfile(saved_pptx_path):
@@ -146,6 +203,70 @@ def when_set_paragraph_alignment_to_centered(context):
 
 # then ====================================================
 
+@then('paragraph.line_spacing is {value_str}')
+def then_paragraph_line_spacing_is_value(context, value_str):
+    value = {
+        'None':   None,
+        '1.0':    1.0,
+        '1.5':    1.5,
+        '2.0':    2.0,
+        '254000': 254000,
+        '304800': 304800,
+    }[value_str]
+    paragraph = context.paragraph
+    assert paragraph.line_spacing == value
+
+
+@then('paragraph.line_spacing.pt {result}')
+def then_paragraph_line_spacing_pt_result(context, result):
+    value, exception = {
+        'raises AttributeError': (None, AttributeError),
+        'is 20.0':               (20.0, None),
+        'is 24.0':               (24.0, None),
+    }[result]
+    line_spacing = context.paragraph.line_spacing
+    if value is not None:
+        assert line_spacing.pt == value
+    if exception is not None:
+        try:
+            line_spacing.pt
+            raise AssertionError('did not raise')
+        except exception:
+            pass
+
+
+@then('paragraph.space_{before_after} is {value_str}')
+def then_paragraph_space_before_is_value(context, before_after, value_str):
+    attr_name = {
+        'before': 'space_before',
+        'after':  'space_after',
+    }[before_after]
+    value = None if value_str == 'None' else int(value_str)
+    paragraph = context.paragraph
+    assert getattr(paragraph, attr_name) == value
+
+
+@then('paragraph.space_{before_after}.pt {result}')
+def then_paragraph_space_before_pt_is_value(context, before_after, result):
+    attr_name = {
+        'before': 'space_before',
+        'after':  'space_after',
+    }[before_after]
+    value, exception = {
+        'raises AttributeError': (None, AttributeError),
+        '== 6.0':                (6.0,  None),
+    }[result]
+    space_before_after = getattr(context.paragraph, attr_name)
+    if value is not None:
+        assert space_before_after.pt == value
+    if exception is not None:
+        try:
+            space_before_after.pt
+            raise AssertionError('did not raise')
+        except exception:
+            pass
+
+
 @then('paragraph.text is the text in the paragraph')
 def then_paragraph_text_is_the_text_in_the_paragraph(context):
     paragraph = context.paragraph
