@@ -81,10 +81,9 @@ class TextFrame(Subshape):
     @property
     def margin_bottom(self):
         """
-        |BaseLength| value representing the inset of text from the bottom
-        text frame border. :meth:`pptx.util.Inches` provides a convenient way
-        of setting the value, e.g. ``text_frame.margin_bottom
-        = Inches(0.05)``.
+        |Length| value representing the inset of text from the bottom text
+        frame border. :meth:`pptx.util.Inches` provides a convenient way of
+        setting the value, e.g. ``text_frame.margin_bottom = Inches(0.05)``.
         """
         return self._bodyPr.bIns
 
@@ -95,7 +94,7 @@ class TextFrame(Subshape):
     @property
     def margin_left(self):
         """
-        Inset of text from left text frame border as |BaseLength| value.
+        Inset of text from left text frame border as |Length| value.
         """
         return self._bodyPr.lIns
 
@@ -106,7 +105,7 @@ class TextFrame(Subshape):
     @property
     def margin_right(self):
         """
-        Inset of text from right text frame border as |BaseLength| value.
+        Inset of text from right text frame border as |Length| value.
         """
         return self._bodyPr.rIns
 
@@ -117,7 +116,7 @@ class TextFrame(Subshape):
     @property
     def margin_top(self):
         """
-        Inset of text from top text frame border as |BaseLength| value.
+        Inset of text from top text frame border as |Length| value.
         """
         return self._bodyPr.tIns
 
@@ -340,13 +339,13 @@ class Font(object):
     @property
     def size(self):
         """
-        Read/write |BaseLength| value or |None|, indicating the font height
-        in English Metric Units (EMU). |None| indicates the font size should
-        be inherited from its style hierarchy, such as a placeholder or
-        document defaults (usually 18pt). |BaseLength| is a subclass of |int|
-        having properties for convenient conversion into points or other
-        length units. Likewise, the :class:`pptx.util.Pt` class allows
-        convenient specification of point values::
+        Read/write |Length| value or |None|, indicating the font height in
+        English Metric Units (EMU). |None| indicates the font size should be
+        inherited from its style hierarchy, such as a placeholder or document
+        defaults (usually 18pt). |Length| is a subclass of |int| having
+        properties for convenient conversion into points or other length
+        units. Likewise, the :class:`pptx.util.Pt` class allows convenient
+        specification of point values::
 
             >> font.size = Pt(24)
             >> font.size
@@ -500,14 +499,76 @@ class _Paragraph(Subshape):
     def level(self, level):
         self._pPr.lvl = level
 
+    @property
+    def line_spacing(self):
+        """
+        Numeric or |Length| value specifying the space between baselines in
+        successive lines of this paragraph. A value of |None| indicates no
+        explicit value is assigned and its effective value is inherited from
+        the paragraph's style hierarchy. A numeric value, e.g. `2` or `1.5`,
+        indicates spacing is applied in multiples of line heights. A |Length|
+        value such as ``Pt(12)`` indicates spacing is a fixed height. The
+        |Pt| value class is a convenient way to apply line spacing in units
+        of points.
+        """
+        pPr = self._p.pPr
+        if pPr is None:
+            return None
+        return pPr.line_spacing
+
+    @line_spacing.setter
+    def line_spacing(self, value):
+        pPr = self._p.get_or_add_pPr()
+        pPr.line_spacing = value
+
     @property
     def runs(self):
         """
-        Immutable sequence of |_Run| instances corresponding to the runs in
+        Immutable sequence of |_Run| objects corresponding to the runs in
         this paragraph.
         """
         return tuple(_Run(r, self) for r in self._element.r_lst)
 
+    @property
+    def space_after(self):
+        """
+        |Length| value specifying the spacing to appear between this
+        paragraph and the subsequent paragraph. A value of |None| indicates
+        no explicit value is assigned and its effective value is inherited
+        from the paragraph's style hierarchy. |Length| objects provide
+        convenience properties, such as ``.pt`` and ``.inches``, that allow
+        easy conversion to various length units.
+        """
+        pPr = self._p.pPr
+        if pPr is None:
+            return None
+        return pPr.space_after
+
+    @space_after.setter
+    def space_after(self, value):
+        pPr = self._p.get_or_add_pPr()
+        pPr.space_after = value
+
+    @property
+    def space_before(self):
+        """
+        |Length| value specifying the spacing to appear between this
+        paragraph and the prior paragraph. A value of |None| indicates no
+        explicit value is assigned and its effective value is inherited from
+        the paragraph's style hierarchy. |Length| objects provide convenience
+        properties, such as ``.pt`` and ``.cm``, that allow easy conversion
+        to various length units.
+        """
+        pPr = self._p.pPr
+        if pPr is None:
+            return None
+        return pPr.space_before
+
+    @space_before.setter
+    def space_before(self, value):
+        pPr = self._p.get_or_add_pPr()
+        pPr.space_before = value
+
     @property
     def text(self):
         """
