@@ -5,10 +5,14 @@ Utility functions and classes that come in handy when working with PowerPoint
 and Open XML.
 """
 
+from __future__ import absolute_import, print_function
+
 import platform
 
+from warnings import warn
 
-class BaseLength(int):
+
+class Length(int):
     """
     Base class for length classes Inches, Emu, Cm, Mm, Pt, and Px. Provides
     properties for converting length values to convenient units.
@@ -74,113 +78,85 @@ class BaseLength(int):
         using 96 pixels/inch on Windows, 72 pixels/inch on all other
         platforms.
         """
+        msg = (
+            'Length.px property is deprecated and will be removed in a futur'
+            'e release.'
+        )
+        warn(msg, UserWarning, stacklevel=2)
+
         # round can somtimes return values like x.999999 which are truncated
         # to x by int(); adding the 0.1 prevents this
         return int(round(self / float(self._EMUS_PER_PX)) + 0.1)
 
 
-class Inches(BaseLength):
+class Inches(Length):
     """
     Convenience constructor for length in inches
     """
     def __new__(cls, inches):
-        emu = int(inches * BaseLength._EMUS_PER_INCH)
-        return BaseLength.__new__(cls, emu)
+        emu = int(inches * Length._EMUS_PER_INCH)
+        return Length.__new__(cls, emu)
 
 
-class Centipoints(BaseLength):
+class Centipoints(Length):
     """
     Convenience constructor for length in hundredths of a point
     """
     def __new__(cls, centipoints):
-        emu = int(centipoints * BaseLength._EMUS_PER_CENTIPOINT)
-        return BaseLength.__new__(cls, emu)
+        emu = int(centipoints * Length._EMUS_PER_CENTIPOINT)
+        return Length.__new__(cls, emu)
 
 
-class Cm(BaseLength):
+class Cm(Length):
     """
     Convenience constructor for length in centimeters
     """
     def __new__(cls, cm):
-        emu = int(cm * BaseLength._EMUS_PER_CM)
-        return BaseLength.__new__(cls, emu)
+        emu = int(cm * Length._EMUS_PER_CM)
+        return Length.__new__(cls, emu)
 
 
-class Emu(BaseLength):
+class Emu(Length):
     """
     Convenience constructor for length in english metric units
     """
     def __new__(cls, emu):
-        return BaseLength.__new__(cls, int(emu))
+        return Length.__new__(cls, int(emu))
 
 
-class Mm(BaseLength):
+class Mm(Length):
     """
     Convenience constructor for length in millimeters
     """
     def __new__(cls, mm):
-        emu = int(mm * BaseLength._EMUS_PER_MM)
-        return BaseLength.__new__(cls, emu)
+        emu = int(mm * Length._EMUS_PER_MM)
+        return Length.__new__(cls, emu)
 
 
-class Pt(BaseLength):
+class Pt(Length):
     """
     Convenience value class for specifying a length in points
     """
     def __new__(cls, points):
-        emu = int(points * BaseLength._EMUS_PER_PT)
-        return BaseLength.__new__(cls, emu)
+        emu = int(points * Length._EMUS_PER_PT)
+        return Length.__new__(cls, emu)
 
 
-class Px(BaseLength):
+class Px(Length):
     """
     Convenience constructor for length in pixels
     """
     def __new__(cls, px):
-        emu = int(px * BaseLength._EMUS_PER_PX)
-        return BaseLength.__new__(cls, emu)
+        """
+        Deprecated. Use one of the other Length classes.
+        """
+        msg = (
+            'Px class is deprecated and will be removed in a future release.'
+        )
+        warn(msg, UserWarning, stacklevel=2)
 
-
-class Collection(object):
-    """
-    Base class for collection classes. May also be used for part collections
-    that don't yet have any custom methods.
-
-    Has the following characteristics.:
-
-    * Container (implements __contains__)
-    * Iterable (delegates __iter__ to |list|)
-    * Sized (implements __len__)
-    * Sequence (delegates __getitem__ to |list|)
-    """
-    def __init__(self):
-        super(Collection, self).__init__()
-        self._values_ = []
-
-    @property
-    def _values(self):
-        """Return read-only reference to collection values (list)."""
-        return self._values_
-
-    def __contains__(self, item):  # __iter__ would do this job by itself
-        """Supports 'in' operator (e.g. 'x in collection')."""
-        return (item in self._values_)
-
-    def __getitem__(self, key):
-        """Provides indexed access, (e.g. 'collection[0]')."""
-        return self._values_.__getitem__(key)
-
-    def __iter__(self):
-        """Supports iteration (e.g. 'for x in collection: pass')."""
-        return self._values_.__iter__()
-
-    def __len__(self):
-        """Supports len() function (e.g. 'len(collection) == 1')."""
-        return len(self._values_)
-
-    def index(self, item):
-        """Supports index method (e.g. '[1, 2, 3].index(2) == 1')."""
-        return self._values_.index(item)
+        emu = int(px * Length._EMUS_PER_PX)
+        return Length.__new__(cls, emu)
 
 
 def lazyproperty(f):
